@@ -417,7 +417,7 @@ xmlSecSimpleKeysMngrSave(const xmlSecKeysMngrPtr mngr,
  * @mngr: the pointer to the simple keys manager.
  * @keyfile: the PEM key file name.
  * @keyPwd: the key file password.
- * @keyPwdCallback: the "ask password" cllback.
+ * @keyPwdCallback: the "ask password" callback.
  * @privateKey: the private/public flag.
  *
  * Reads the key from a PEM file @keyfile.
@@ -718,4 +718,15 @@ xmlSecSimpleKeysMngrSetCertsFlags(xmlSecKeysMngrPtr mngr, unsigned long flags) {
 }
 
 
+void
+xmlSecSimpleKeysMngrSetVerifyDepth(xmlSecKeysMngrPtr mngr, int depth) {
+    xmlSecAssert(mngr != NULL);
+    xmlSecAssert(mngr->x509Data != NULL);
+    xmlSecAssert(((xmlSecX509StorePtr)mngr->x509Data)->xst != NULL);
+    
+    if (depth > 0) {
+       ((xmlSecX509StorePtr)mngr->x509Data)->xst->depth = depth ;
+    }
+}
 #endif /* XMLSEC_NO_X509 */
+
